Release 1.2.4 (02 Apr 2016)
===========================

* Add --dry-run command line option.
* Fix incorrect LICENSE.


Release 1.2.3 (01 Apr 2015)
===========================

* Update/fix RPM packaging.
* Add missing build depends on python3-alogger.
* Debian: Only run python3 tests.


Release 1.2.2 (31 Oct 2014)
===========================

* Support parsing log files before sending.
* Updates to sample config file.


Release 1.2.1 (27 Oct 2014)
===========================

* Initial release.
